*****************
``suext`` Utility
*****************

**Installation**

``pip install suext``

**Usage:**

- ``suext <filename>``
- ``suext <dirname>``
- ``suext -h|--help``

**Options:**

- ``<filename>`` Full or relative path to filename for showing file extension.
- ``<dirname>`` Full or relative path to directory for showing all files extension in this directories.
- ``-h --help`` Show help screen.
